import { BigNumber, BigNumberish, ethers, Signer } from 'ethers';
import { Provider, TransactionReceipt } from '@ethersproject/providers';
import { LandListing as LandListingContract } from '@motif-foundation/listing/dist/typechain';
export interface LandList {
    approved: boolean;
    amount: BigNumber;
    startsAt: BigNumber;
    duration: BigNumber;
    firstBidTime: BigNumber;
    listPrice: BigNumber;
    listType: number;
    intermediaryFeePercentage: number;
    tokenOwner: string;
    bidder: string;
    intermediary: string;
    listCurrency: string;
}
export declare class LandListing {
    readonly chainId: number;
    readonly readOnly: boolean;
    readonly signerOrProvider: Signer | Provider;
    readonly landListing: LandListingContract;
    landAddress: string;
    constructor(signerOrProvider: Signer | Provider, chainId: number, landAddress?: string);
    fetchListing(listingId: BigNumberish): Promise<LandList>;
    fetchListingFromTransactionReceipt(receipt: TransactionReceipt): Promise<LandList | null>;
    createListing(tokenId: BigNumberish, startsAt: BigNumberish, duration: BigNumberish, listPrice: BigNumberish, listType: number, intermediary: string, intermediaryFeePercentages: number, listCurrency: string, tokenAddress?: string): Promise<ethers.ContractTransaction>;
    setListingApproval(listingId: BigNumberish, approved: boolean): Promise<ethers.ContractTransaction>;
    setListingDropApproval(listingId: BigNumberish, approved: boolean, startsAt: BigNumberish): Promise<ethers.ContractTransaction>;
    setListingListPrice(listingId: BigNumberish, listPrice: BigNumberish): Promise<ethers.ContractTransaction>;
    createBid(listingId: BigNumberish, amount: BigNumberish): Promise<ethers.ContractTransaction>;
    endFixedPriceListing(listingId: BigNumberish, amount: BigNumberish): Promise<ethers.ContractTransaction>;
    endListing(listingId: BigNumberish): Promise<ethers.ContractTransaction>;
    cancelListing(listingId: BigNumberish): Promise<ethers.ContractTransaction>;
}
